############ EACH SCRIPT MUST START WITH THE FOLLOWING TWO LINES  ############
tryCatch({source('C:/Users/sharriso/Dropbox/ucpgood/R/ucpub_config.R')},
        warning=function(warning_message){source('ucpub_config.R')})
############ EACH SCRIPT MUST START WITH THE PREVIOUS TWO LINES  #############

library(stargazer)

# Set "control" as reference category
data <- within(data, kind <- relevel(factor(kind), ref='control'))
data_clean <- within(data_clean, kind <- relevel(factor(kind), ref='control'))


data_c = subset(data, kind == 'control')
data_t = subset(data, kind != 'control')
data_l = subset(data, kind == 0.3)
data_h = subset(data, kind == 0.6)
data_lt = subset(data, kind != 0.6)
data_ht = subset(data, kind != 0.3)


# Both "oth_avg_vint_1" (visible peer choices) and "oth_avg_contr_1" (actual
# peer contributions) work worse than "oth_avg_int_1" (all peer choices) as
# controls (in the sense that treatment (interaction) effects are only
# marginally, or not, significant.

# Regressions without controls work worse than with: particularly important
# seems to be "female".

# Replacing regressions on subsets with interactions with H and L makes very
# little difference.

# Not controlling for round makes virtually no difference.





ra_tr_c <- rlm(actual_contribution ~ is_treatment + round + female + age + ethnic, data=data)

ra_tir_c <- rlm(actual_contribution ~ is_treatment + oth_contr_1 + round + female + age + ethnic, data=data)
ra_tr_ch <- rlm(actual_contribution ~ is_treatment + round + female + age + ethnic, data=data_ht)
ra_tr_cl <- rlm(actual_contribution ~ is_treatment + round + female + age + ethnic, data=data_lt)
ra_trH_c <- rlm(actual_contribution ~ is_treatment + H + round + female + age + ethnic, data=data)

ra_txir_cl <- rlm(actual_contribution ~ oth_contr_1*is_treatment + round + female + age + ethnic, data=data_lt)
ra_txir_ch <- rlm(actual_contribution ~ oth_contr_1*is_treatment + round +female + age + ethnic, data=data_ht)


ra_txir <- rlm(actual_contribution ~ oth_contr_1*is_treatment + round + female + age + ethnic,
           data=data)
ra_txirH <- rlm(actual_contribution ~ oth_contr_1*is_treatment + oth_contr_1*H + round + female + age + ethnic,
           data=data)

# This is problematic: shocks are larger the lower are contributions, and
# contributions have inertia, so it is natural that large shocks are followed
# by lower contributions.
#r_tsr_c <- rlm(actual_contribution ~ is_treatment + shock_1 + round + female + age + ethnic, data=data)

ra_tisrC_c <- rlm(actual_contribution ~ is_treatment + oth_tot_int_1 + shock_1 + contribution_1 + round + female + age + ethnic, data=data)

ra_tf_c <- rlm(actual_contribution ~ is_treatment + force_round_1 + round + female + age + ethnic, data=data)

ra_txr_c <- rlm(actual_contribution ~ is_treatment*round + female + age + ethnic, data=data)

ra_txri_c <- rlm(actual_contribution ~ is_treatment*round + oth_contr_1 + female + age + ethnic, data=data)


models = list(ra_tr_c,
              ra_txir,
              ra_trH_c,
              ra_txirH,
              ra_tisrC_c,
              ra_txr_c
              )

tabify(models,
order=c("Constant", "is_treatment", "oth_contr_1:is_treatment",
"is_treatment:round", "^oth_contr_1$", "^H", "oth_contr_1:H",
"contribution_1",
"oth_tot_int_1", "shock_1", "round"),
#column.labels = c("", "", "", "T $\\neq$ H", "T $\\neq$ L"),
covariate.labels = c("Constant", "Treatment",
"Treatment $\\times$ Peer contr.", "Treatment $\\times$ Round",
"Peer contr.", "HIGH", "Peer contr. $\\times$ HIGH",
"Own contribution", "Peer int. contr.", "Shock size",  "Round"),
omit=c("female", "age", "ethnic"),
out="tables/actual.tex")


r_tr_c <- rlm(contribution ~ is_treatment + round + female + age + ethnic, data=data)

r_tir_c <- rlm(contribution ~ is_treatment + oth_contr_1 + round + female + age + ethnic, data=data)

r_tr_ch <- rlm(contribution ~ is_treatment + round + female + age + ethnic, data=data_ht)
r_tr_cl <- rlm(contribution ~ is_treatment + round + female + age + ethnic, data=data_lt)

r_trH_c <- rlm(contribution ~ is_treatment + H + round + female + age + ethnic, data=data)


r_txir_cl <- rlm(contribution ~ oth_contr_1*is_treatment + round + female + age + ethnic, data=data_lt)
r_txir_ch <- rlm(contribution ~ oth_contr_1*is_treatment + round +female + age + ethnic, data=data_ht)

r_txirH <- rlm(contribution ~ oth_contr_1*is_treatment + oth_contr_1*H + round + female + age + ethnic,
           data=data)



r_txir <- rlm(contribution ~ oth_contr_1*is_treatment + round + female + age + ethnic,
           data=data)
           


# This is problematic: shocks are larger the lower are contributions, and
# contributions have inertia, so it is natural that large shocks are followed
# by lower contributions.
#r_tsr_c <- rlm(contribution ~ is_treatment + shock_1 + round + female + age + ethnic, data=data)

r_tisrC_c <- rlm(contribution ~ is_treatment + contribution_1 + oth_tot_int_1 + shock_1 + round + female + age + ethnic, data=data)

r_tf_c <- rlm(contribution ~ is_treatment + force_round_1 + round + female + age + ethnic, data=data)

r_txr_c <- rlm(contribution ~ is_treatment*round + female + age + ethnic, data=data)

r_txri_c <- rlm(contribution ~ is_treatment*round + oth_contr_1 + female + age + ethnic, data=data)

models = list(r_tr_c,

              r_txir,
              r_trH_c,
              r_txirH,
              r_tisrC_c,
              r_txr_c
              )

tabify(models,
order=c("Constant", "is_treatment", "oth_contr_1:is_treatment",
"is_treatment:round", "^oth_contr_1$", "^H", "oth_contr_1:H",
"contribution_1",
"oth_tot_int_1", "shock_1", "round"),
#column.labels = c("", "", "", "T $\\neq$ H", "T $\\neq$ L"),
covariate.labels = c("Constant", "Treatment",
"Treatment $\\times$ Peer contr.", "Treatment $\\times$ Round",
"Peer contr.", "HIGH", "Peer contr. $\\times$ HIGH",
"Own contribution", "Peer int. contr.", "Shock size",  "Round"),
omit=c("female", "age", "ethnic"),
out="tables/cross_treat.tex",
)
# oth_contr_1 -> Peers contr.
# oth_tot_int_1 -> Peers int.
# contribution_1 -> Own contr.
# forced -> Own forcing
# force_peer_1 ->  Peer forcing
# shocked -> shock size
# shock_peer -> peer shock size

r_f_tc <- rlm(contribution ~ forced_1 + female + age + ethnic, data=data_t)

r_fr_tc <- rlm(contribution ~ forced_1 + round + female + age + ethnic, data=data_t)
r_frC_tc <- rlm(contribution ~ forced_1 + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

# With round x forced interaction - results mentioned in the paper
#r_fxrC_tc <- rlm(contribution ~ forced_1*round + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)


r_sr_tc <- rlm(contribution ~ shocked_1 + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

r_for_tc <- rlm(contribution ~ forced_1 + oth_avg_int_1 + round + female + age + ethnic, data=data_t)

r_f_ch <- rlm(contribution ~ forced_1 + female + age + ethnic, data=data_l)
r_f_cl <- rlm(contribution ~ forced_1 + female + age + ethnic, data=data_h)
r_fk_ct <- rlm(contribution ~ forced_1 + H + female + age + ethnic, data=data_t)

# With forced x HIGH interaction, mentioned in the paper:
r_fxkr_ct <- rlm(contribution ~ forced_1*H + round + female + age + ethnic, data=data_t)
r_sxkrC_ct <- rlm(contribution ~ shocked_1*H + contribution_1 + round + female + age + ethnic, data=data_t)

r_p_t <- rlm(contribution ~ force_peer_1, data=data_t)

r_fp_t <- rlm(contribution ~ forced_1 + force_peer_1, data=data_t)

r_fpr_t <- rlm(contribution ~ forced_1 + force_peer_1 + round, data=data_t)

r_fpro_t <- rlm(contribution ~ forced_1 + force_peer_1 + round + oth_avg_int_1, data=data_t)

r_fprv_t <- rlm(contribution ~ forced_1 + force_peer_1 + round + oth_avg_vint_1, data=data_t)

r_for_ct <- rlm(contribution ~ forced_1 + oth_avg_contr_1 + shock_peer_1 + round + female + age + ethnic, data=data_t)

r_pr_ct <- rlm(contribution ~ force_peer_1 + round + female + age + ethnic, data=data_t)

r_prC_ct <- rlm(contribution ~ force_peer_1 + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

# With round x forced interaction - results mentioned in the paper
#r_prC_ct <- rlm(contribution ~ force_peer_1*round + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

r_fprC_ct <- rlm(contribution ~ forced_1 + force_peer_1 + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

r_SxkrC_ct <- rlm(contribution ~ shock_peer_1*H + contribution_1 + round + female + age + ethnic, data=data_t)

r_SrC_ct <- rlm(contribution ~ shock_peer_1 + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

r_por_ct <- rlm(contribution ~ force_peer_1 + oth_avg_contr_1 + shock_peer_1 + round + female + age + ethnic, data=data_t)

r_pxkr_ct <- rlm(contribution ~ force_peer_1*H + round + female + age + ethnic, data=data_t)

r_fxkrC_ct <- rlm(contribution ~ forced_1*H + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)

r_pxkrC_ct <- rlm(contribution ~ force_peer_1*H + contribution_1 + oth_tot_int_1 + round + female + age + ethnic, data=data_t)


r_fpr_ct <- rlm(contribution ~ forced_1 + force_peer_1 + round + female + age + ethnic, data=data_t)

r_sprC_ct <- rlm(contribution ~ shocked_1 + contribution_1 + force_peer_1 + round + female + age + ethnic, data=data_t)

r_sSrC_ct <- rlm(contribution ~ shocked_1 + contribution_1 + oth_tot_int_1 + shock_peer_1 + round + female + age + ethnic, data=data_t)

r_fpor_ct <- rlm(contribution ~ forced_1 + force_peer_1 + oth_avg_contr_1 + shock_peer_1 + round + female + age + ethnic, data=data_t)

r_spor_ct <- rlm(contribution ~ shocked_1 + force_peer_1 + oth_avg_contr_1 + shock_peer_1 + round + female + age + ethnic, data=data_t)

print("Placebo")
# Placebo:
pl_r_fg_t <- rlm(contribution ~ forced__1 + force_peer__1, data=data_t)


models = list(r_frC_tc,
              r_sr_tc,
              r_prC_ct,
              r_SrC_ct,
              r_fprC_ct,
              r_sSrC_ct

              # Mentioned in the paper:
#              , r_fxkrC_ct, r_pxkrC_ct
              )

tabify(models,
order=c("Constant", "forced_1", "force_peer_1", "H"),
covariate.labels = c("Constant", "Forced self", "Forced peer",
"Shock size self", "Shock size peer", "Own contribution",
"Peer int. contr.", "Round"),
omit=c("female", "age", "ethnic"),
out="tables/within_treat.tex")

models = list(r_fr_tc,
              r_frC_tc,
              r_pr_ct,
              r_prC_ct,
              r_fprC_ct
              )

tabify(models,
order=c("Constant", "forced_1", "force_peer_1", "H"),
#covariate.labels = c("Constant", "Forced$_{t-1}$", "GForced$_{t-1}$",
#"PeerForced$_{t-1}$", "Round", "Peers$_{t-1}$"),
omit=c("female", "age", "ethnic"),
out="tables/within_treat_alt.tex")




###############################################################################


print("Only first round")

test <- rlm(contribution ~ is_treatment + female + age + ethnic, data=subset(data, round == 1))

print(summary(test))
test <- rlm(contribution ~ L + H + female + age + ethnic, data=subset(data, round == 1))

print(summary(test))

print("Only clean rounds")

test <- rlm(contribution ~ is_treatment + round + female + age + ethnic, data=data_clean)

print(summary(test))
test <- rlm(contribution ~ L + H + round + female + age + ethnic, data=data_clean)

print(summary(test))

###############################################################################

print("Distance from forcing")

data_dist = subset(data, r_round != -1 & r_round < 9)

data_dist$distance = data_dist$r_round
# Doesn't work: not only does it consider as "0" observations that were several
# rounds before any forcing event, but it also compares obs. after a "peer"
# shock to obs. that preceded a "self" shock.
#data_dist$distance[data_dist$distance == -1] <- 0

test <- rlm(contribution ~ factor(r_round)*r_self + female + age + ethnic,
           data=data_dist)

dist_reg = summary(test)

print(dist_reg)

dist_reg_ci = confint(test)

print(dist_reg_ci)

save(dist_reg, dist_reg_ci,
     file='output/force_dist.RData')

# Without round:
#test_lin <- rlm(contribution ~ distance*r_self + female + age + ethnic,
#           data=data_dist)

#print(summary(test_lin))

test_lin <- rlm(contribution ~ distance + round + female + age + ethnic,
           data=data_dist)

print(summary(test_lin))

test_lin_int <- rlm(contribution ~ distance*r_self + round + female + age + ethnic,
           data=data_dist)

print(summary(test_lin_int))


library(lmtest)
coeftest(test_lin, vcov = vcovCL, cluster = data_dist$uid, show.se = TRUE)

coeftest(test_lin_int, vcov = vcovCL, cluster = data_dist$uid, show.se = TRUE)
