############ EACH SCRIPT MUST START WITH THE FOLLOWING TWO LINES  ############
tryCatch({source('C:/Users/sharriso/Dropbox/ucpgood/R/ucpub_config.R')},
        warning=function(warning_message){source('ucpub_config.R')})
############ EACH SCRIPT MUST START WITH THE PREVIOUS TWO LINES  #############

library(multcomp)

# Set "control" as reference category
data <- within(data, kind <- relevel(factor(kind), ref='control'))
data_clean <- within(data_clean, kind <- relevel(factor(kind), ref='control'))


data_c = subset(data, kind == 'control')
data_t = subset(data, kind != 'control')
data_l = subset(data, kind == 0.3)
data_h = subset(data, kind == 0.6)
data_lt = subset(data, kind != 0.6)
data_ht = subset(data, kind != 0.3)


###############################################################################
# Linear combination within specification
###############################################################################

print("Within-regression")

ra_txr_c <- rlm(actual_contribution ~ is_treatment*round + female + age + ethnic, data=data)

summary(glht(ra_txr_c, linfct = c("is_treatment:round + round = 0")))


r_txr_c <- rlm(contribution ~ is_treatment*round + female + age + ethnic, data=data)

summary(glht(r_txr_c, linfct = c("is_treatment:round + round = 0")))

###############################################################################
# Difference across specification
###############################################################################

# The approach employed below combines the one recommended the docs of Stata's
# "suest" (under "Example 3", the stacking data approach) with the command glht
# from package multcomp to test a linear combination of coefficients.

# Using the "geese" command should have allowed simpler code... but it is
# impossibly slow in estimating.

print("Between-regressions:")
print("Treatment variable when adding/removing its interaction with Peer contr.")

# Create a copy of data...
data_copy = data.frame(data)
# ... denote it with a different "model"...
data$model = 1
data_copy$model = 2
# ... move all coefficient to be used to new variable names...
data_copy$is_treatment_2 = data_copy$is_treatment
data_copy$round_2 = data_copy$round
data_copy$female_2 = data_copy$female
data_copy$age_2 = data_copy$age
data_copy$ethnic_2 = data_copy$ethnic

data$is_treatment_2 = 0
data$round_2 = 0
data$female_2 = 0
data$age_2 = 0
data$ethnic_2 = 0

data_copy$is_treatment = 0
data_copy$round = 0
data_copy$female = 0
data_copy$age = 0
data_copy$ethnic = 0

# ... switch off the additional variable in the copy...
data_copy$oth_contr_1 = 0
# (notice that this is the only step that cannot be reused across different
# specifications)

# ... and stack the copy to the original:
data_stacked = rbind(data, data_copy)


# Actually useless:
#data_stacked = data_stacked[ , colSums(is.na(data_stacked))==0]
# For check:
#print("Missing variables")
#sapply(data_stacked, function(x) sum(is.na(x)))

r_txir <- rlm(actual_contribution ~ oth_contr_1*is_treatment + round + female + age + ethnic +
is_treatment_2 + round_2 + female_2 + age_2 + ethnic_2 + model,
           data=data_stacked)


print(summary(r_txir))

names(coef(r_txir))


summary(glht(r_txir, linfct = c("is_treatment - is_treatment_2 = 0")))

quit()


###############################################################################
# Difference across samples
###############################################################################

# Create copies of data...
data_lt_copy = data.frame(data_lt)
data_ht_copy = data.frame(data_ht)

# ... denote them with a different "model"...
data_lt_copy$model = 1
data_ht_copy$model = 2

# ... move all coefficient to be used to new variable names inside ht...
data_ht_copy$is_treatment_2 = data_ht_copy$is_treatment
data_ht_copy$is_treatment = "False"
data_lt_copy$is_treatment_2 = "False"

data_ht_copy$round_2 = data_ht_copy$round
data_ht_copy$female_2 = data_ht_copy$female
data_ht_copy$age_2 = data_ht_copy$age
data_ht_copy$ethnic_2 = data_ht_copy$ethnic
data_ht_copy$oth_contr_1_2 = data_ht_copy$oth_contr_1

data_lt_copy$round_2 = 0
data_lt_copy$female_2 = 0
data_lt_copy$age_2 = 0
data_lt_copy$ethnic_2 = 0
data_lt_copy$oth_contr_1_2 = 0

data_ht_copy$round = 0
data_ht_copy$female = 0
data_ht_copy$age = 0
data_ht_copy$ethnic = 0
data_ht_copy$oth_contr_1 = 0

# ... and stack the two copies:
data_stacked = rbind(data_lt_copy, data_ht_copy)

r_txir <- rlm(actual_contribution ~ is_treatment + round + female + age + ethnic +
is_treatment_2 + round_2 + female_2 + age_2 + ethnic_2 + model,
           data=data_stacked)

#print(summary(reg))

names(coef(r_txir))

print(summary(r_txir))

print("Column 3 vs. 5")

summary(glht(r_txir, linfct = c("is_treatment - is_treatment_2True = 0")))


r_txir <- rlm(actual_contribution ~ is_treatment + oth_contr_1*is_treatment + round + female + age + ethnic +
is_treatment_2 + oth_contr_1_2*is_treatment_2 + round_2 + female_2 + age_2 + ethnic_2 + model,
           data=data_stacked)

#print(summary(reg))

names(coef(r_txir))

print(summary(r_txir))

print("Column 4 vs. 6")

summary(glht(r_txir, linfct = c("is_treatment - is_treatment_2True = 0")))

