DATA_PATH = '../data/all_sessions.csv'
R_DATA_PATH = 'rdata'
TABLES_PATH = 'tables'


saveme <- function(what, name){
mypath = file.path(R_DATA_PATH, paste(name, "RData", sep="."))
regsum <- what
save(regsum, file = mypath)
}

library(stargazer)

tabify <- function(models, out, omit=NULL, covariate.labels=NULL,
omit.stat = c("aic", "ll", "f", "ser", "adj.rsq"), order=NULL, column.labels=NULL,
dep.var.labels.include=FALSE, dep.var.labels=NULL,
summaries=NULL){

n <-length(models)
actual_models = vector("list", n)
coefs = vector("list", n)
ses = vector("list", n)
p = vector("list", n)

for (i in 1:n)
    {
    model <- models[[i]]
    if (!is.null(summaries) && !is.null(summaries[[i]]))
        {
        # Take standard errors from model summary if available
        actual_models[[i]] = model
        coefs[[i]] = NULL
        ses[[i]] = coef(summaries[[i]])[, 2]
        p[[i]] = coef(summaries[[i]])[,4]
        }
    else if (is.element("robust_se", names(model)))
        {
        # This was created by "rlm" and carries its own summary
        actual_models[[i]] = model
        coefs[[i]] = NULL
        ses[[i]] = model$robust_se
        }
    else if (is.element("mfxest", names(model)))
        {
        # If passed probit marginal effects, retrieve original model
        actual_models[[i]] <- model$fit
        coefs[[i]] = model$mfxest[,1]
        ses[[i]] = model$mfxest[,2]
        p[[i]] = model$mfxest[,4]
        }
    else
        {
        # Normal model
        actual_models[[i]] = model
        coefs[[i]] = NULL
        ses[[i]] = NULL
        p[[i]] = NULL
        }    
    }

stargazer(actual_models, out=out,
omit=omit, covariate.labels=covariate.labels, omit.stat=omit.stat, order=order,
dep.var.labels=dep.var.labels, dep.var.labels.include = dep.var.labels.include,

coef=coefs,
se=ses,
p=p,

column.labels=column.labels,
float=FALSE,
dep.var.caption = "",
omit.table.layout="n",
no.space=TRUE,
model.names=FALSE

#,
# AER:
#star.cutoffs = NA
,
star.cutoffs = c(.1, .05, .01),
star.char = c("*", "**", "***")
# To show p-values:
#, report=("vc*p")
)

}


# From:
#https://raw.githubusercontent.com/IsidoreBeautrelet/economictheoryblog/master/robust_summary.R
#source('robust_summary.R')
source('load_expdata.R')

library(sandwich)

rlm <- function(formula, data, cluster){
reg = lm(formula=formula, data=data)
# Change data$uid to data$group for SE clustered at the group level:
cov1         <- vcovCL(reg, cluster = data$uid)
robust_se    <- sqrt(diag(cov1))
reg$robust_se = robust_se
return(reg)
}

